@@ -45,12 +45,15 @@ import aws_cdk.aws_sns
 
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
-class AddHeader(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.AddHeader"):
+class AddHeader(
+    metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.AddHeader"
+):
     """Adds a header to the received email.
 
     stability
     :stability: experimental
     """
+
     def __init__(self, *, name: str, value: str) -> None:
         """
         :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
@@ -64,7 +67,9 @@ class AddHeader(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Add
         jsii.create(AddHeader, self, [props])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, _rule: aws_cdk.aws_ses.IReceiptRule) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+    def bind(
+        self, _rule: aws_cdk.aws_ses.IReceiptRule
+    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
         """Returns the receipt rule action specification.
 
         :param _rule: -
@@ -75,8 +80,12 @@ class AddHeader(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Add
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-ses-actions.AddHeaderProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'value': 'value'})
-class AddHeaderProps():
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-ses-actions.AddHeaderProps",
+    jsii_struct_bases=[],
+    name_mapping={"name": "name", "value": "value"},
+)
+class AddHeaderProps:
     def __init__(self, *, name: str, value: str) -> None:
         """Construction properties for a add header action.
 
@@ -87,8 +96,8 @@ class AddHeaderProps():
         :stability: experimental
         """
         self._values = {
-            'name': name,
-            'value': value,
+            "name": name,
+            "value": value,
         }
 
     @builtins.property
@@ -102,7 +111,7 @@ class AddHeaderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def value(self) -> str:
@@ -114,7 +123,7 @@ class AddHeaderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('value')
+        return self._values.get("value")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -123,7 +132,9 @@ class AddHeaderProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AddHeaderProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AddHeaderProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
@@ -133,7 +144,14 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
     stability
     :stability: experimental
     """
-    def __init__(self, *, sender: str, template: "BounceTemplate", topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        sender: str,
+        template: "BounceTemplate",
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+    ) -> None:
         """
         :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
         :param template: The template containing the message, reply code and status code.
@@ -147,7 +165,9 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
         jsii.create(Bounce, self, [props])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, _rule: aws_cdk.aws_ses.IReceiptRule) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+    def bind(
+        self, _rule: aws_cdk.aws_ses.IReceiptRule
+    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
         """Returns the receipt rule action specification.
 
         :param _rule: -
@@ -158,9 +178,19 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-ses-actions.BounceProps", jsii_struct_bases=[], name_mapping={'sender': 'sender', 'template': 'template', 'topic': 'topic'})
-class BounceProps():
-    def __init__(self, *, sender: str, template: "BounceTemplate", topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-ses-actions.BounceProps",
+    jsii_struct_bases=[],
+    name_mapping={"sender": "sender", "template": "template", "topic": "topic"},
+)
+class BounceProps:
+    def __init__(
+        self,
+        *,
+        sender: str,
+        template: "BounceTemplate",
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+    ) -> None:
         """Construction properties for a bounce action.
 
         :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
@@ -171,10 +201,11 @@ class BounceProps():
         :stability: experimental
         """
         self._values = {
-            'sender': sender,
-            'template': template,
+            "sender": sender,
+            "template": template,
         }
-        if topic is not None: self._values["topic"] = topic
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def sender(self) -> str:
@@ -186,7 +217,7 @@ class BounceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('sender')
+        return self._values.get("sender")
 
     @builtins.property
     def template(self) -> "BounceTemplate":
@@ -195,7 +226,7 @@ class BounceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('template')
+        return self._values.get("template")
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
@@ -207,7 +238,7 @@ class BounceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -216,16 +247,27 @@ class BounceProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'BounceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "BounceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-class BounceTemplate(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.BounceTemplate"):
+class BounceTemplate(
+    metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.BounceTemplate"
+):
     """A bounce template.
 
     stability
     :stability: experimental
     """
-    def __init__(self, *, message: str, smtp_reply_code: str, status_code: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        message: str,
+        smtp_reply_code: str,
+        status_code: typing.Optional[str] = None,
+    ) -> None:
         """
         :param message: Human-readable text to include in the bounce message.
         :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
@@ -234,7 +276,9 @@ class BounceTemplate(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-action
         stability
         :stability: experimental
         """
-        props = BounceTemplateProps(message=message, smtp_reply_code=smtp_reply_code, status_code=status_code)
+        props = BounceTemplateProps(
+            message=message, smtp_reply_code=smtp_reply_code, status_code=status_code
+        )
 
         jsii.create(BounceTemplate, self, [props])
 
@@ -293,9 +337,23 @@ class BounceTemplate(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-action
         return jsii.get(self, "props")
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-ses-actions.BounceTemplateProps", jsii_struct_bases=[], name_mapping={'message': 'message', 'smtp_reply_code': 'smtpReplyCode', 'status_code': 'statusCode'})
-class BounceTemplateProps():
-    def __init__(self, *, message: str, smtp_reply_code: str, status_code: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-ses-actions.BounceTemplateProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "message": "message",
+        "smtp_reply_code": "smtpReplyCode",
+        "status_code": "statusCode",
+    },
+)
+class BounceTemplateProps:
+    def __init__(
+        self,
+        *,
+        message: str,
+        smtp_reply_code: str,
+        status_code: typing.Optional[str] = None,
+    ) -> None:
         """Construction properties for a BounceTemplate.
 
         :param message: Human-readable text to include in the bounce message.
@@ -306,10 +364,11 @@ class BounceTemplateProps():
         :stability: experimental
         """
         self._values = {
-            'message': message,
-            'smtp_reply_code': smtp_reply_code,
+            "message": message,
+            "smtp_reply_code": smtp_reply_code,
         }
-        if status_code is not None: self._values["status_code"] = status_code
+        if status_code is not None:
+            self._values["status_code"] = status_code
 
     @builtins.property
     def message(self) -> str:
@@ -318,7 +377,7 @@ class BounceTemplateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('message')
+        return self._values.get("message")
 
     @builtins.property
     def smtp_reply_code(self) -> str:
@@ -329,7 +388,7 @@ class BounceTemplateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('smtp_reply_code')
+        return self._values.get("smtp_reply_code")
 
     @builtins.property
     def status_code(self) -> typing.Optional[str]:
@@ -340,7 +399,7 @@ class BounceTemplateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('status_code')
+        return self._values.get("status_code")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -349,7 +408,9 @@ class BounceTemplateProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'BounceTemplateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "BounceTemplateProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.enum(jsii_type="@aws-cdk/aws-ses-actions.EmailEncoding")
@@ -359,6 +420,7 @@ class EmailEncoding(enum.Enum):
     stability
     :stability: experimental
     """
+
     BASE64 = "BASE64"
     """Base 64.
 
@@ -372,6 +434,7 @@ class EmailEncoding(enum.Enum):
     :stability: experimental
     """
 
+
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda"):
     """Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
@@ -379,7 +442,14 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
     stability
     :stability: experimental
     """
-    def __init__(self, *, function: aws_cdk.aws_lambda.IFunction, invocation_type: typing.Optional["LambdaInvocationType"]=None, topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        function: aws_cdk.aws_lambda.IFunction,
+        invocation_type: typing.Optional["LambdaInvocationType"] = None,
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+    ) -> None:
         """
         :param function: The Lambda function to invoke.
         :param invocation_type: The invocation type of the Lambda function. Default: Event
@@ -388,12 +458,16 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
         stability
         :stability: experimental
         """
-        props = LambdaProps(function=function, invocation_type=invocation_type, topic=topic)
+        props = LambdaProps(
+            function=function, invocation_type=invocation_type, topic=topic
+        )
 
         jsii.create(Lambda, self, [props])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, rule: aws_cdk.aws_ses.IReceiptRule) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+    def bind(
+        self, rule: aws_cdk.aws_ses.IReceiptRule
+    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
         """Returns the receipt rule action specification.
 
         :param rule: -
@@ -411,6 +485,7 @@ class LambdaInvocationType(enum.Enum):
     stability
     :stability: experimental
     """
+
     EVENT = "EVENT"
     """The function will be invoked asynchronously.
 
@@ -428,9 +503,24 @@ class LambdaInvocationType(enum.Enum):
     :stability: experimental
     """
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-ses-actions.LambdaProps", jsii_struct_bases=[], name_mapping={'function': 'function', 'invocation_type': 'invocationType', 'topic': 'topic'})
-class LambdaProps():
-    def __init__(self, *, function: aws_cdk.aws_lambda.IFunction, invocation_type: typing.Optional["LambdaInvocationType"]=None, topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-ses-actions.LambdaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "function": "function",
+        "invocation_type": "invocationType",
+        "topic": "topic",
+    },
+)
+class LambdaProps:
+    def __init__(
+        self,
+        *,
+        function: aws_cdk.aws_lambda.IFunction,
+        invocation_type: typing.Optional["LambdaInvocationType"] = None,
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+    ) -> None:
         """Construction properties for a Lambda action.
 
         :param function: The Lambda function to invoke.
@@ -441,10 +531,12 @@ class LambdaProps():
         :stability: experimental
         """
         self._values = {
-            'function': function,
+            "function": function,
         }
-        if invocation_type is not None: self._values["invocation_type"] = invocation_type
-        if topic is not None: self._values["topic"] = topic
+        if invocation_type is not None:
+            self._values["invocation_type"] = invocation_type
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def function(self) -> aws_cdk.aws_lambda.IFunction:
@@ -453,7 +545,7 @@ class LambdaProps():
         stability
         :stability: experimental
         """
-        return self._values.get('function')
+        return self._values.get("function")
 
     @builtins.property
     def invocation_type(self) -> typing.Optional["LambdaInvocationType"]:
@@ -465,7 +557,7 @@ class LambdaProps():
         stability
         :stability: experimental
         """
-        return self._values.get('invocation_type')
+        return self._values.get("invocation_type")
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
@@ -477,7 +569,7 @@ class LambdaProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -486,7 +578,9 @@ class LambdaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'LambdaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "LambdaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
@@ -496,7 +590,15 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
     stability
     :stability: experimental
     """
-    def __init__(self, *, bucket: aws_cdk.aws_s3.IBucket, kms_key: typing.Optional[aws_cdk.aws_kms.IKey]=None, object_key_prefix: typing.Optional[str]=None, topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        bucket: aws_cdk.aws_s3.IBucket,
+        kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        object_key_prefix: typing.Optional[str] = None,
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+    ) -> None:
         """
         :param bucket: The S3 bucket that incoming email will be saved to.
         :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
@@ -506,12 +608,19 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
         stability
         :stability: experimental
         """
-        props = S3Props(bucket=bucket, kms_key=kms_key, object_key_prefix=object_key_prefix, topic=topic)
+        props = S3Props(
+            bucket=bucket,
+            kms_key=kms_key,
+            object_key_prefix=object_key_prefix,
+            topic=topic,
+        )
 
         jsii.create(S3, self, [props])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, rule: aws_cdk.aws_ses.IReceiptRule) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+    def bind(
+        self, rule: aws_cdk.aws_ses.IReceiptRule
+    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
         """Returns the receipt rule action specification.
 
         :param rule: -
@@ -522,9 +631,25 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
         return jsii.invoke(self, "bind", [rule])
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-ses-actions.S3Props", jsii_struct_bases=[], name_mapping={'bucket': 'bucket', 'kms_key': 'kmsKey', 'object_key_prefix': 'objectKeyPrefix', 'topic': 'topic'})
-class S3Props():
-    def __init__(self, *, bucket: aws_cdk.aws_s3.IBucket, kms_key: typing.Optional[aws_cdk.aws_kms.IKey]=None, object_key_prefix: typing.Optional[str]=None, topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-ses-actions.S3Props",
+    jsii_struct_bases=[],
+    name_mapping={
+        "bucket": "bucket",
+        "kms_key": "kmsKey",
+        "object_key_prefix": "objectKeyPrefix",
+        "topic": "topic",
+    },
+)
+class S3Props:
+    def __init__(
+        self,
+        *,
+        bucket: aws_cdk.aws_s3.IBucket,
+        kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        object_key_prefix: typing.Optional[str] = None,
+        topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+    ) -> None:
         """Construction properties for a S3 action.
 
         :param bucket: The S3 bucket that incoming email will be saved to.
@@ -536,11 +661,14 @@ class S3Props():
         :stability: experimental
         """
         self._values = {
-            'bucket': bucket,
+            "bucket": bucket,
         }
-        if kms_key is not None: self._values["kms_key"] = kms_key
-        if object_key_prefix is not None: self._values["object_key_prefix"] = object_key_prefix
-        if topic is not None: self._values["topic"] = topic
+        if kms_key is not None:
+            self._values["kms_key"] = kms_key
+        if object_key_prefix is not None:
+            self._values["object_key_prefix"] = object_key_prefix
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def bucket(self) -> aws_cdk.aws_s3.IBucket:
@@ -549,7 +677,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('bucket')
+        return self._values.get("bucket")
 
     @builtins.property
     def kms_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
@@ -561,7 +689,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('kms_key')
+        return self._values.get("kms_key")
 
     @builtins.property
     def object_key_prefix(self) -> typing.Optional[str]:
@@ -573,7 +701,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('object_key_prefix')
+        return self._values.get("object_key_prefix")
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
@@ -585,7 +713,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -594,7 +722,9 @@ class S3Props():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'S3Props(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "S3Props(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
@@ -604,7 +734,13 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
     stability
     :stability: experimental
     """
-    def __init__(self, *, topic: aws_cdk.aws_sns.ITopic, encoding: typing.Optional["EmailEncoding"]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        topic: aws_cdk.aws_sns.ITopic,
+        encoding: typing.Optional["EmailEncoding"] = None,
+    ) -> None:
         """
         :param topic: The SNS topic to notify.
         :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
@@ -617,7 +753,9 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
         jsii.create(Sns, self, [props])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, _rule: aws_cdk.aws_ses.IReceiptRule) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+    def bind(
+        self, _rule: aws_cdk.aws_ses.IReceiptRule
+    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
         """Returns the receipt rule action specification.
 
         :param _rule: -
@@ -628,9 +766,18 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-ses-actions.SnsProps", jsii_struct_bases=[], name_mapping={'topic': 'topic', 'encoding': 'encoding'})
-class SnsProps():
-    def __init__(self, *, topic: aws_cdk.aws_sns.ITopic, encoding: typing.Optional["EmailEncoding"]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-ses-actions.SnsProps",
+    jsii_struct_bases=[],
+    name_mapping={"topic": "topic", "encoding": "encoding"},
+)
+class SnsProps:
+    def __init__(
+        self,
+        *,
+        topic: aws_cdk.aws_sns.ITopic,
+        encoding: typing.Optional["EmailEncoding"] = None,
+    ) -> None:
         """Construction properties for a SNS action.
 
         :param topic: The SNS topic to notify.
@@ -640,9 +787,10 @@ class SnsProps():
         :stability: experimental
         """
         self._values = {
-            'topic': topic,
+            "topic": topic,
         }
-        if encoding is not None: self._values["encoding"] = encoding
+        if encoding is not None:
+            self._values["encoding"] = encoding
 
     @builtins.property
     def topic(self) -> aws_cdk.aws_sns.ITopic:
@@ -651,7 +799,7 @@ class SnsProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     @builtins.property
     def encoding(self) -> typing.Optional["EmailEncoding"]:
@@ -663,7 +811,7 @@ class SnsProps():
         stability
         :stability: experimental
         """
-        return self._values.get('encoding')
+        return self._values.get("encoding")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -672,7 +820,9 @@ class SnsProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'SnsProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "SnsProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
@@ -682,7 +832,10 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
     stability
     :stability: experimental
     """
-    def __init__(self, *, topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+
+    def __init__(
+        self, *, topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None
+    ) -> None:
         """
         :param topic: The SNS topic to notify when the stop action is taken.
 
@@ -694,7 +847,9 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
         jsii.create(Stop, self, [props])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, _rule: aws_cdk.aws_ses.IReceiptRule) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
+    def bind(
+        self, _rule: aws_cdk.aws_ses.IReceiptRule
+    ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
         """Returns the receipt rule action specification.
 
         :param _rule: -
@@ -705,9 +860,15 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-ses-actions.StopProps", jsii_struct_bases=[], name_mapping={'topic': 'topic'})
-class StopProps():
-    def __init__(self, *, topic: typing.Optional[aws_cdk.aws_sns.ITopic]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-ses-actions.StopProps",
+    jsii_struct_bases=[],
+    name_mapping={"topic": "topic"},
+)
+class StopProps:
+    def __init__(
+        self, *, topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None
+    ) -> None:
         """Construction properties for a stop action.
 
         :param topic: The SNS topic to notify when the stop action is taken.
@@ -715,9 +876,9 @@ class StopProps():
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if topic is not None: self._values["topic"] = topic
+        self._values = {}
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
@@ -726,7 +887,7 @@ class StopProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -735,7 +896,9 @@ class StopProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'StopProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "StopProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
